**********
Output API
**********

Outputs are responsible for playing audio.

.. warning::

    A stable output API is not available yet, as we've only implemented a
    single output module.

.. automodule:: mopidy.outputs.base
    :synopsis: Base class for outputs
    :members:


Output implementations
======================

* :mod:`mopidy.outputs.gstreamer`
